summaryrefslogtreecommitdiffstats
path: root/sbin/natd/natd.c
diff options
context:
space:
mode:
Diffstat (limited to 'sbin/natd/natd.c')
-rw-r--r--sbin/natd/natd.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/sbin/natd/natd.c b/sbin/natd/natd.c
index 38f923f..40f68c2 100644
--- a/sbin/natd/natd.c
+++ b/sbin/natd/natd.c
@@ -169,9 +169,11 @@ int main (int argc, char** argv)
openlog ("natd", LOG_CONS | LOG_PID | (verbose ? LOG_PERROR : 0),
logFacility);
/*
* Check that valid aliasing address has been given.
*/
- if (aliasAddr.s_addr == INADDR_NONE && ifName == NULL)
+ if (aliasAddr.s_addr == INADDR_NONE && ifName == NULL &&
+ !(PacketAliasSetMode(0,0) & PKT_ALIAS_PROXY_ONLY))
errx (1, "aliasing address not given");
if (aliasAddr.s_addr != INADDR_NONE && ifName != NULL)
OpenPOWER on IntegriCloud
@@ -169,9 +169,11 @@ int main (int argc, char** argv)
logFacility);
/*
- * Check that valid aliasing address has been given.
+ * If not doing the transparent proxying only,
+ * check that valid aliasing address has been given.
*/